@@ -11,7 +11,7 @@
  *  tunneling and relaying of packets of any protocol.
  *
  *
- *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl, 
+ *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl,
  *                          Christian Pointner <satp@wirdorange.org>
  *
  *  This file is part of Anytun.
@@ -56,7 +56,7 @@ public:
   void init(std::string addrPort);
 
   std::string addr;
-	std::string port;
+  std::string port;
 };
 typedef std::list<OptionHost> HostList;
 std::istream& operator>>(std::istream& stream, OptionHost& host);
@@ -66,12 +66,12 @@ class OptionNetwork
 public:
   OptionNetwork() : net_addr(""), prefix_length(0) {};
   OptionNetwork(std::string network) { init(network); };
-  OptionNetwork(std::string n, u_int16_t p) : net_addr(n), prefix_length(p) {};
+  OptionNetwork(std::string n, uint16_t p) : net_addr(n), prefix_length(p) {};
 
   void init(std::string network);
 
   std::string net_addr;
-  u_int16_t prefix_length;
+  uint16_t prefix_length;
 };
 typedef std::list<OptionNetwork> NetworkList;
 std::istream& operator>>(std::istream& stream, OptionNetwork& network);
@@ -131,7 +131,7 @@ public:
   Options& setLocalSyncAddr(std::string l);
   std::string getLocalSyncPort();
   Options& setLocalSyncPort(std::string l);
-	HostList getRemoteSyncHosts();
+  HostList getRemoteSyncHosts();
 
   std::string getDevName();
   Options& setDevName(std::string d);
@@ -154,8 +154,8 @@ public:
   Options& setCipher(std::string c);
   std::string getAuthAlgo();
   Options& setAuthAlgo(std::string a);
-  u_int32_t getAuthTagLength();
-  Options& setAuthTagLength(u_int32_t a);
+  uint32_t getAuthTagLength();
+  Options& setAuthTagLength(uint32_t a);
   std::string getKdPrf();
   Options& setKdPrf(std::string k);
   role_t getRole();
@@ -171,15 +171,18 @@ public:
 private:
   Options();
   ~Options();
-  Options(const Options &l);
-  void operator=(const Options &l);
+  Options(const Options& l);
+  void operator=(const Options& l);
 
   static Options* inst;
   static ::Mutex instMutex;
-  class instanceCleaner {
-    public: ~instanceCleaner() {
-      if(Options::inst != 0)
+  class instanceCleaner
+  {
+  public:
+    ~instanceCleaner() {
+      if(Options::inst != 0) {
         delete Options::inst;
+      }
     }
   };
   friend class instanceCleaner;
@@ -208,7 +211,7 @@ private:
   OptionHost remote_;
 
   OptionHost local_sync_;
-	HostList remote_sync_hosts_;
+  HostList remote_sync_hosts_;
 
   std::string dev_name_;
   std::string dev_type_;
@@ -222,7 +225,7 @@ private:
 
   std::string cipher_;
   std::string auth_algo_;
-  u_int32_t auth_tag_length_;
+  uint32_t auth_tag_length_;
   std::string kd_prf_;
   role_t role_;
   std::string passphrase_;
