@@ -11,7 +11,7 @@
  *  tunneling and relaying of packets of any protocol.
  *
  *
- *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl, 
+ *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl,
  *                          Christian Pointner <satp@wirdorange.org>
  *
  *  This file is part of Anytun.
@@ -66,15 +66,18 @@ public:
 private:
   SignalController() {};
   ~SignalController() {};
-  SignalController(const SignalController &s);
-  void operator=(const SignalController &s);
+  SignalController(const SignalController& s);
+  void operator=(const SignalController& s);
 
   static SignalController* inst;
   static Mutex instMutex;
-  class instanceCleaner {
-    public: ~instanceCleaner() {
-      if(SignalController::inst != NULL)
+  class instanceCleaner
+  {
+  public:
+    ~instanceCleaner() {
+      if(SignalController::inst != NULL) {
         delete SignalController::inst;
+      }
     }
   };
   friend class instanceCleaner;
