@@ -11,7 +11,7 @@
  *  tunneling and relaying of packets of any protocol.
  *
  *
- *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl, 
+ *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl,
  *                          Christian Pointner <satp@wirdorange.org>
  *
  *  This file is part of Anytun.
@@ -37,18 +37,18 @@
 
 //using asio::ip::tcp;
 
-SyncServer::SyncServer(std::string localaddr, std::string port, ConnectCallback onConnect) 
+SyncServer::SyncServer(std::string localaddr, std::string port, ConnectCallback onConnect)
   : onConnect_(onConnect)
 {
   gResolver.resolveTcp(localaddr, port, boost::bind(&SyncServer::onResolve, this, _1), boost::bind(&SyncServer::onResolvError, this, _1));
 }
 
-SyncServer::~SyncServer() 
+SyncServer::~SyncServer()
 {
   std::list<AcceptorsElement>::iterator it = acceptors_.begin();
-  for(;it != acceptors_.end(); ++it) {
-/// this might be a needed by a running thread, TODO cleanup
-//    delete(it->acceptor_);
+  for(; it != acceptors_.end(); ++it) {
+    /// this might be a needed by a running thread, TODO cleanup
+    //    delete(it->acceptor_);
   }
 }
 
@@ -56,16 +56,18 @@ void SyncServer::onResolve(SyncTcpConnection::proto::resolver::iterator& it)
 {
   while(it != SyncTcpConnection::proto::resolver::iterator()) {
     SyncTcpConnection::proto::endpoint e = *it;
-    
+
     AcceptorsElement acceptor;
     acceptor.acceptor_ = new SyncTcpConnection::proto::acceptor(io_service_);
-    if(!acceptor.acceptor_)
+    if(!acceptor.acceptor_) {
       AnytunError::throwErr() << "memory error";
+    }
 
     acceptor.acceptor_->open(e.protocol());
 #ifndef _MSC_VER
-    if(e.protocol() == boost::asio::ip::tcp::v6())
+    if(e.protocol() == boost::asio::ip::tcp::v6()) {
       acceptor.acceptor_->set_option(boost::asio::ip::v6_only(true));
+    }
 #endif
     acceptor.acceptor_->set_option(boost::asio::socket_base::reuse_address(true));
     acceptor.acceptor_->bind(e);
@@ -86,7 +88,7 @@ void SyncServer::onResolve(SyncTcpConnection::proto::resolver::iterator& it)
 void SyncServer::onResolvError(const std::runtime_error& e)
 {
   cLog.msg(Log::PRIO_ERROR) << "sync server bind/listen failed: " << e.what();
-      // TODO: stop daemon??
+  // TODO: stop daemon??
 }
 
 void SyncServer::run()
@@ -98,8 +100,9 @@ void SyncServer::run()
 void SyncServer::send(std::string message)
 {
   Lock lock(mutex_);
-  for(std::list<SyncTcpConnection::pointer>::iterator it = conns_.begin() ;it != conns_.end(); ++it)
+  for(std::list<SyncTcpConnection::pointer>::iterator it = conns_.begin() ; it != conns_.end(); ++it) {
     (*it)->Send(message);
+  }
 }
 
 void SyncServer::start_accept()
@@ -107,12 +110,12 @@ void SyncServer::start_accept()
   Lock lock(mutex_);
 
   std::list<AcceptorsElement>::iterator it = acceptors_.begin();
-  for(;it != acceptors_.end(); ++it) {
+  for(; it != acceptors_.end(); ++it) {
     if(!it->started_) {
-      SyncTcpConnection::pointer new_connection = SyncTcpConnection::create(it->acceptor_->io_service());
+      SyncTcpConnection::pointer new_connection = SyncTcpConnection::create(it->acceptor_->get_io_service());
       conns_.push_back(new_connection);
       it->acceptor_->async_accept(new_connection->socket(),
-                             boost::bind(&SyncServer::handle_accept, this, new_connection, boost::asio::placeholders::error, it));
+                                  boost::bind(&SyncServer::handle_accept, this, new_connection, boost::asio::placeholders::error, it));
       it->started_ = true;
     }
   }
@@ -120,7 +123,7 @@ void SyncServer::start_accept()
 
 void SyncServer::handle_accept(SyncTcpConnection::pointer new_connection, const boost::system::error_code& error, std::list<AcceptorsElement>::iterator it)
 {
-  if (!error) {
+  if(!error) {
     cLog.msg(Log::PRIO_INFO) << "new sync client connected from " << new_connection->socket().remote_endpoint();
 
     new_connection->onConnect = onConnect_;
