@@ -11,7 +11,7 @@
  *  tunneling and relaying of packets of any protocol.
  *
  *
- *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl, 
+ *  Copyright (C) 2007-2009 Othmar Gsenger, Erwin Nindl,
  *                          Christian Pointner <satp@wirdorange.org>
  *
  *  This file is part of Anytun.
@@ -47,23 +47,25 @@ void WinService::install()
   SC_HANDLE schService;
   char szPath[MAX_PATH];
 
-  if(!GetModuleFileNameA(NULL, szPath, MAX_PATH))
+  if(!GetModuleFileNameA(NULL, szPath, MAX_PATH)) {
     AnytunError::throwErr() << "Error on GetModuleFileName: " << AnytunErrno(GetLastError());
+  }
 
   schSCManager = OpenSCManagerA(NULL, NULL, SC_MANAGER_ALL_ACCESS);
-  if(NULL == schSCManager)
+  if(NULL == schSCManager) {
     AnytunError::throwErr() << "Error on OpenSCManager: " << AnytunErrno(GetLastError());
+  }
 
-  schService = CreateServiceA(schSCManager, SVC_NAME, SVC_NAME, SERVICE_ALL_ACCESS, SERVICE_WIN32_OWN_PROCESS, 
+  schService = CreateServiceA(schSCManager, SVC_NAME, SVC_NAME, SERVICE_ALL_ACCESS, SERVICE_WIN32_OWN_PROCESS,
                               SERVICE_DEMAND_START, SERVICE_ERROR_NORMAL, szPath, NULL, NULL, NULL, NULL, NULL);
   if(schService == NULL) {
     CloseServiceHandle(schSCManager);
     AnytunError::throwErr() << "Error on CreateService: " << AnytunErrno(GetLastError());
   }
 
-  std::cout << "Service installed successfully" << std::endl; 
+  std::cout << "Service installed successfully" << std::endl;
 
-  CloseServiceHandle(schService); 
+  CloseServiceHandle(schService);
   CloseServiceHandle(schSCManager);
 }
 
@@ -73,8 +75,9 @@ void WinService::uninstall()
   SC_HANDLE schService;
 
   schSCManager = OpenSCManagerA(NULL, NULL, SC_MANAGER_ALL_ACCESS);
-  if(NULL == schSCManager)
+  if(NULL == schSCManager) {
     AnytunError::throwErr() << "Error on OpenSCManager: " << AnytunErrno(GetLastError());
+  }
 
   schService = OpenServiceA(schSCManager, SVC_NAME, SERVICE_ALL_ACCESS);
   if(schService == NULL) {
@@ -83,14 +86,14 @@ void WinService::uninstall()
   }
 
   if(!DeleteService(schService)) {
-    CloseServiceHandle(schService); 
+    CloseServiceHandle(schService);
     CloseServiceHandle(schSCManager);
     AnytunError::throwErr() << "Error on DeleteService: " << AnytunErrno(GetLastError());
   }
 
-  std::cout << "Service uninstalled successfully" << std::endl; 
+  std::cout << "Service uninstalled successfully" << std::endl;
 
-  CloseServiceHandle(schService); 
+  CloseServiceHandle(schService);
   CloseServiceHandle(schSCManager);
 }
 
@@ -101,27 +104,28 @@ void WinService::start()
     {NULL, NULL}
   };
 
-  if(!StartServiceCtrlDispatcherA(DispatchTable))
+  if(!StartServiceCtrlDispatcherA(DispatchTable)) {
     AnytunError::throwErr() << "Error on StartServiceCtrlDispatcher: " << AnytunErrno(GetLastError());
+  }
 }
 
 int real_main(int argc, char* argv[], WinService& service);
 
-VOID WINAPI WinService::main(DWORD dwArgc, LPTSTR *lpszArgv)
+VOID WINAPI WinService::main(DWORD dwArgc, LPTSTR* lpszArgv)
 {
   WinService service;
 
   service.status_handle_ = RegisterServiceCtrlHandlerA(SVC_NAME, WinService::ctrlHandler);
-  if(!service.status_handle_) { 
+  if(!service.status_handle_) {
     cLog.msg(Log::PRIO_ERROR) << "Error on RegisterServiceCtrlHandler: " << AnytunErrno(GetLastError());
     return;
   }
-  service.status_.dwServiceType = SERVICE_WIN32_OWN_PROCESS; 
-  service.status_.dwServiceSpecificExitCode = 0;    
+  service.status_.dwServiceType = SERVICE_WIN32_OWN_PROCESS;
+  service.status_.dwServiceSpecificExitCode = 0;
   service.reportStatus(SERVICE_START_PENDING, NO_ERROR);
-  
+
   real_main(dwArgc, lpszArgv, service);
-  
+
   service.reportStatus(SERVICE_STOPPED, NO_ERROR);
 }
 
@@ -133,13 +137,15 @@ VOID WINAPI WinService::ctrlHandler(DWORD dwCtrl)
 int WinService::handleCtrlSignal(int sig, const std::string& msg)
 {
   switch(sig) {
-    case SERVICE_CONTROL_STOP: {
-      reportStatus(SERVICE_STOP_PENDING, NO_ERROR);
-      cLog.msg(Log::PRIO_NOTICE) << "received service stop signal, exitting";
-      return 1;
-    }
-    case SERVICE_CONTROL_INTERROGATE: break;
-    default: break;
+  case SERVICE_CONTROL_STOP: {
+    reportStatus(SERVICE_STOP_PENDING, NO_ERROR);
+    cLog.msg(Log::PRIO_NOTICE) << "received service stop signal, exitting";
+    return 1;
+  }
+  case SERVICE_CONTROL_INTERROGATE:
+    break;
+  default:
+    break;
   }
   reportStatus(status_.dwCurrentState, NO_ERROR);
 
@@ -155,38 +161,40 @@ void WinService::reportStatus(DWORD dwCurrentState, DWORD dwWin32ExitCode)
   status_.dwWaitHint = 0;
 
   if((dwCurrentState == SERVICE_START_PENDING) ||
-     (dwCurrentState == SERVICE_STOP_PENDING))
+      (dwCurrentState == SERVICE_STOP_PENDING)) {
     status_.dwControlsAccepted = 0;
-  else 
+  } else {
     status_.dwControlsAccepted = SERVICE_ACCEPT_STOP;
+  }
 
   if((dwCurrentState == SERVICE_RUNNING) ||
-     (dwCurrentState == SERVICE_STOPPED))
+      (dwCurrentState == SERVICE_STOPPED)) {
     status_.dwCheckPoint = 0;
-  else
+  } else {
     status_.dwCheckPoint = dwCheckPoint++;
+  }
 
   SetServiceStatus(status_handle_, &status_);
 }
 
 void WinService::initPrivs(std::string const& username, std::string const& groupname)
 {
-// nothing here
+  // nothing here
 }
 
 void WinService::dropPrivs()
 {
-// nothing here
+  // nothing here
 }
 
 void WinService::chroot(std::string const& dir)
 {
-// nothing here
+  // nothing here
 }
 
 void WinService::daemonize()
 {
-// nothing here
+  // nothing here
 }
 
 bool WinService::isDaemonized()
